<div><label for="department_abbreviation">Department Abbreviation:</label> <input class="department_abbreviation" id="department_abbreviation" name="department_abbreviation" value="{{search.department_abbreviation}}" type="text" size="8"></div>
