<div><label for="view_unpublished">View Unpublished:</label> <input class="view_unpublished" id="view_unpublished" name="view_unpublished" value="true"{% if search.view_unpublished == "true" %} checked="checked"{% endif %} type="checkbox"></div>
